==========================================================================
``psyclone.domain.nemo.transformations.create_nemo_invoke_schedule_trans``
==========================================================================

.. automodule:: psyclone.domain.nemo.transformations.create_nemo_invoke_schedule_trans

   .. contents::
      :local:

.. currentmodule:: psyclone.domain.nemo.transformations.create_nemo_invoke_schedule_trans


Classes
=======

- :py:class:`CreateNemoInvokeScheduleTrans`:
  Transform a generic PSyIR Routine into a NEMO InvokeSchedule.


.. autoclass:: CreateNemoInvokeScheduleTrans
   :members:

   .. rubric:: Inheritance
   .. inheritance-diagram:: CreateNemoInvokeScheduleTrans
      :parts: 1
